# API Reference

This section contains the complete API reference for PyMedSec.

```{toctree}
:maxdepth: 2

modules
kms
crypto
sanitize
audit
config
```

## Core Modules

### PyMedSec Main Module

```{automodule} pymedsec
   :members:
   :undoc-members:
   :show-inheritance:
```

### Public API

```{automodule} pymedsec.public_api
   :members:
   :undoc-members:
   :show-inheritance:
```
